@@ -1,5 +1,4 @@
-#include <stdio.h>
-#include <stdlib.h>
+#include "definitions.h"
 
 void asnewick(FILE* stream, const int* nbr_labels, const int* label_parent, const int* nbr_nodes,
 		const int* node_parent, const double* node_pos, const double* xlim, char** const hap_name);
